circleCoords: Store the radii of the circles and the corresponding values

View source: R/radial_plot.R

circleCoordsR Documentation

Store the radii of the circles and the corresponding values

Description

This function stores the radii of the circles and the corresponding value for each circle.

Usage

circleCoords(itemCoordsDF, extraCircles = 0)

Arguments

itemCoordsDF

Data frame wih item coordinates.

extraCircles

Number of circles drawn beyond those required to include the points.

Value

A data frame containing the radius and the corresponding value for each circle.


henna documentation built on Feb. 17, 2026, 9:08 a.m.