| createLabelDFTemplate | R Documentation |
This function creates a label data frame to be used by plotting functions that label selected points.
createLabelDFTemplate(
df,
xCol = 1,
yCol = 2,
labeledPoints = NULL,
labelOutside = FALSE,
labXThr = NULL,
labYThr = NULL,
adjFunX = identity,
adjFunY = identity,
compFunX = `>=`,
compFunY = `>=`
)
df |
A data frame. |
xCol |
Column representing the |
yCol |
Column representing the |
labeledPoints |
Point labels to be displayed on the plot. Default is
|
labelOutside |
Display labels for points specified by
|
labXThr |
Threshold used to plot labels based on |
labYThr |
Threshold used to plot labels based on |
adjFunX |
Function used to adjust |
adjFunY |
Function used to adjust |
compFunX |
Function used for the selection of |
compFunY |
Function used for the selection of |
A label data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.