dfPoint: Extract point from data frame of points.

View source: R/utils.R

dfPointR Documentation

Extract point from data frame of points.

Description

This function extracts a point from a data frame of points.

Usage

dfPoint(df, i, pointCoords = c(1, 2))

Arguments

df

A data frame containing the coordinates of the points.

i

Row name or index.

pointCoords

The row names or indices of point coordinates.

Value

A numeric vector containing the point coordinates.


henna documentation built on Feb. 17, 2026, 9:08 a.m.