distFreq: Map values to distances from the center and find the...

View source: R/radial_plot.R

distFreqR Documentation

Map values to distances from the center and find the frequency of these distances

Description

This function interprets values as distances from a center (high values = low distances) and calculates the frequencies of these distances.

Usage

distFreq(valuesDF)

Arguments

valuesDF

A data frame with names on the first column and positive integers on the second column.

Details

Used later to draw concentric circles with the frequencies representing the number of points on a circle of the same radius.

Value

A data frame of distance frequencies.


henna documentation built on Feb. 17, 2026, 9:08 a.m.