View source: R/documentation.R
| documentFun | R Documentation |
This function is used internally to help document other functions.
documentFun(
title = NULL,
xLab = "x",
yLab = "y",
legendTitle = "Legend",
legendLabs = c("a", "b"),
legendPos = "right",
palette = "Spectral",
viridisPal = "turbo",
labeledPoints = NULL,
labelType = "free",
labelOutside = TRUE,
labelSize = 2.5,
labelColor = "black",
labelRepulsion = 1,
labelPull = 1,
maxOverlaps = 50,
boxPadding = 0.2,
labelPadding = 0.1,
labelSegWidth = 0.4,
pointSize = 0.8,
pointShape = 1,
legendTitleSize = 10,
legendTextSize = 10,
axisTextSize = 12,
axisTitleSize = 12,
xAngle = 45,
vJust = 0.6,
margins = margin(0, -10, -10, -10),
theme = "linedraw",
pvalOffset = 1.00000023069254e-317,
...
)
title |
Plot title. |
xLab |
x axis label. |
yLab |
y axis label. |
legendTitle |
Legend title. |
legendLabs |
Legend labels. |
legendPos |
Legend position. |
palette |
Color palette. |
viridisPal |
Viridis palette. |
labeledPoints |
Point labels to be displayed on the plot. |
labelType |
Whether to draw a box around labels (option 'boxed') or not (option 'free'). Default is 'free'. |
labelSize |
Label size. |
labelColor |
Label color. |
labelRepulsion |
Repulsion strength between labels. |
labelPull |
Attraction strength between a text label and its data point. |
maxOverlaps |
Maximum number of allowed overlaps. |
boxPadding |
Amount of padding around box. |
labelPadding |
Amount of padding around label. |
labelSegWidth |
Thickness of segment connecting label to point. |
pointSize |
Point size. |
pointShape |
Point shape. |
legendTitleSize |
Legend title size. |
legendTextSize |
Legend text size. |
axisTextSize |
Axis text size. |
axisTitleSize |
Axis title size. |
xAngle |
Angle of x axis text. |
vJust |
Vertical justification in [0, 1]. |
margins |
Plot margins. Must be a vector of size 4 listing the desired top, right, bottom and left margin, in that order. |
theme |
Plot theme. |
pvalOffset |
Offset added to p-values to avoid infinite values when taking logarithms. |
... |
Additional arguments passed to |
NULL. This function is only used internally for
documentation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.