networkPlotDF: Prepare data frame for network plot

View source: R/network_plot.R

networkPlotDFR Documentation

Prepare data frame for network plot

Description

This function prepares a data frame for network plot.

Usage

networkPlotDF(df, rankCol = "rank")

Arguments

df

Data frame.

rankCol

Name of the rank column.

Value

A data frame ready to serve as input to networkPlot.


henna documentation built on Feb. 17, 2026, 9:08 a.m.