pointsOnCircle: Generate the coordinates of points on a circle centered at...

View source: R/radial_plot.R

pointsOnCircleR Documentation

Generate the coordinates of points on a circle centered at origin

Description

This function generates nPoints on a circle of radius r centered at origin.

Usage

pointsOnCircle(r, nPoints, seed = 50)

Arguments

r

Radius.

nPoints

Number of points.

seed

Random seed.

Value

A data frame with the coordinates of the points.


henna documentation built on Feb. 17, 2026, 9:08 a.m.