| quadBorders | R Documentation |
This function finds the coordinates of the points establishing the four divisions of the hull
quadBorders(pointsDF, xInt, yInt, vCoords, hCoords)
pointsDF |
A data frame with the x and y coordinates of the points. |
xInt |
The coordinate where the vertical line intersects the x axis. |
yInt |
The coordinate where the horizontal line intersects the y axis. |
vCoords |
The y coordinates of the two points where the vertical line intersects the convex hull. |
hCoords |
The x coordinates of the two points where the horizontal line intersects the convex hull. |
A data frame with 2 columns representing the 12 points (not unique) determining the boundaries of the hull divisions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.