| rankPlot | R Documentation |
This function creates a rank plot.
rankPlot(
df,
title = NULL,
summarize = TRUE,
viridisPal = "turbo",
xLab = "Item",
yLab = "Rank count",
legendTitle = "Rank",
sigDigits = NULL,
labelSize = 2.5,
labelColor = "black",
labelFace = c("plain", "bold", "italic", "bold-italic"),
legendTextSize = 10,
legendTitleSize = 10,
axisTextSize = 12,
axisTitleSize = 12,
xAngle = 45,
vJust = 0.6,
labelScalingFactor = 0.9,
labelOffset = 0.05,
...
)
df |
A data frame with ranks as columns and items as rows, or a
summary data frame generated with |
title |
Plot title. |
summarize |
Whether to summarize the ranks with |
viridisPal |
Viridis palette. |
xLab |
Label of x axis. |
yLab |
y axis label. |
legendTitle |
Legend title. |
sigDigits |
Number of significant digits used when displaying mean
ranks. If |
labelSize |
Size of label marking average rank for each item.
Ignored if |
labelColor |
Color of label marking average rank for each item.
Ignored if |
labelFace |
Font face of label marking average rank for each item. Must
be one among 'plain', 'bold', 'italic' and 'bold-italic'.
Ignored if |
legendTextSize |
Legend text size. |
legendTitleSize |
Legend title size. |
axisTextSize |
Axis text size. |
axisTitleSize |
Axis title size. |
xAngle |
Angle of x axis text. |
vJust |
Vertical justification in [0, 1]. |
labelScalingFactor |
Scaling factor used when displaying mean ranks.
Ignored if |
labelOffset |
Vertical offset used when displaying mean ranks.
Ignored if |
... |
Additional arguments passed to |
An object of class gg.
df <- do.call(cbind, lapply(seq(30), function(i) sample(10, 10)))
rownames(df) <- paste0('M', seq(10))
colnames(df) <- paste0('R', seq(30))
rankPlot(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.