| rankSummary | R Documentation |
This function creates a summary of multiple ranks provided for input items.
rankSummary(df)
df |
A data frame with ranks as columns and items as rows. |
A rank summary data frame with three columns: 'Rank', 'Item' and 'Count'.
df <- do.call(cbind, lapply(seq(30), function(i) sample(10, 10)))
rownames(df) <- paste0('M', seq(10))
colnames(df) <- paste0('R', seq(30))
rankSummary(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.