reorderDF: Sort a data frame by the first column and convert the second...

View source: R/tile_plot.R

reorderDFR Documentation

Sort a data frame by the first column and convert the second to a factor

Description

This function sort a data frame by the first column and convert the second to a factor.

Usage

reorderDF(df)

Arguments

df

A data frame.

Value

An object of class gg.

Examples

df <- data.frame(a = c(2, 4, 1, 3, 6),
b = c(2, 8, 3, 19, 3))
reorderDF(df)


henna documentation built on Feb. 17, 2026, 9:08 a.m.