| splitHull | R Documentation |
This function splits the convex hull in two parts along a vertical and a horizontal line.
splitHull(
p,
pointsDF,
hullSegments,
xInt = NULL,
yInt = NULL,
lineColor = "navy",
lineWidth = 0.3,
lineType = c("dashed", "solid", "dotted", "dotdash", "longdash", "twodash"),
legendLabs = paste0("Group ", seq(4)),
alpha = 0.2
)
p |
A ggplot object representing the hull. |
pointsDF |
A data frame with the x and y coordinates of the points. |
hullSegments |
Data frame of segments that define the convex hull. |
xInt |
The coordinate where the vertical line intersects the x axis. |
yInt |
The coordinate where the horizontal line intersects the y axis. |
lineColor |
The color of the horizontal and vertical dividing lines,
if provided. If |
lineWidth |
The width of the horizontal and vertical dividing lines.
Ignored if |
lineType |
The type of the horizontal and vertical dividing lines.
Choose between 'dashed','solid', 'dotted', 'dotdash', 'longdash' and
'twodash'. Default is 'dashed'. Ignored if |
legendLabs |
Legend labels. |
alpha |
Opaqueness level. |
An object of class gg showing the hull split along the input
axes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.