| circleCoords | R Documentation |
This function stores the radii of the circles and the corresponding value for each circle.
circleCoords(itemCoordsDF, extraCircles = 0)
itemCoordsDF |
Data frame wih item coordinates. |
extraCircles |
Number of circles drawn beyond those required to include the points. |
A data frame containing the radius and the corresponding value for each circle.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.