| dfEuclidean | R Documentation |
This function finds the Euclidean distance between two points in a data frame.
dfEuclidean(df, i, j, pointCoords = c(1, 2), replaceZero = 0)
df |
A data frame containing the coordinates of the points. |
i |
Row name or index. |
j |
Row name or index |
pointCoords |
The row names or indices of point coordinates. |
replaceZero |
Value to replace zero with. If set to 0, no replacement will occur. |
A numeric value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.