| dfPoint | R Documentation |
This function extracts a point from a data frame of points.
dfPoint(df, i, pointCoords = c(1, 2))
df |
A data frame containing the coordinates of the points. |
i |
Row name or index. |
pointCoords |
The row names or indices of point coordinates. |
A numeric vector containing the point coordinates.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.