| distFreq | R Documentation |
This function interprets values as distances from a center (high values = low distances) and calculates the frequencies of these distances.
distFreq(valuesDF)
valuesDF |
A data frame with names on the first column and positive integers on the second column. |
Used later to draw concentric circles with the frequencies representing the number of points on a circle of the same radius.
A data frame of distance frequencies.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.