| networkPlotDF | R Documentation |
This function prepares a data frame for network plot.
networkPlotDF(df, rankCol = "rank")
df |
Data frame. |
rankCol |
Name of the rank column. |
A data frame ready to serve as input to networkPlot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.