| pointsOnCircle | R Documentation |
This function generates nPoints on a circle of radius r centered at origin.
pointsOnCircle(r, nPoints, seed = 50)
r |
Radius. |
nPoints |
Number of points. |
seed |
Random seed. |
A data frame with the coordinates of the points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.