powered by
This function creates a summary of multiple ranks provided for input items.
rankSummary(df)
A rank summary data frame with three columns: 'Rank', 'Item' and 'Count'.
A data frame with ranks as columns and items as rows.
df <- do.call(cbind, lapply(seq(30), function(i) sample(10, 10))) rownames(df) <- paste0('M', seq(10)) colnames(df) <- paste0('R', seq(30)) rankSummary(df)
Run the code above in your browser using DataLab