| reorderDF | R Documentation |
This function sort a data frame by the first column and convert the second to a factor.
reorderDF(df)
df |
A data frame. |
An object of class gg.
df <- data.frame(a = c(2, 4, 1, 3, 6),
b = c(2, 8, 3, 19, 3))
reorderDF(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.